@ECHO OFF

REM Note: 
REM This Tool requires Update Tool V 6.0.1 or later
REM ################################################################################
REM Configuration Section

SET touchToolPath=USB HD\TouchTool.exe
SET settingsFolderPath=SD Card\Touch\Settings\
SET calibrationsFolderPath=SD Card\Touch\Calibrations\
SET calibrationsSourceFolderPath=USB HD\Calibrations\

set backupFolderPath=\USB HD\Backup
set bootloaderImage=bootloader.imx
set configBlockFile=configBlock.cfg
set filesystemFile=filesystem.i7f
set registryFile=registry.i7r
set splashImage=splash.tss
set wince7=os.bin
set updateToolPath=Windows\update.exe

REM Configuration Section end
REM ################################################################################

ECHO ================================
ECHO = Accu-Gold T2 Updater v1.1 =
ECHO ================================
ECHO.

ECHO Activating display...
"%touchToolPath%" -displayOn > NUL
ECHO OK

ECHO Terminating running application...
"%touchToolPath%" -kill > NUL
"%touchToolPath%" -delayOneSec > NUL 
"%touchToolPath%" -delayOneSec > NUL
"%touchToolPath%" -delayOneSec > NUL
"%touchToolPath%" -delayOneSec > NUL
"%touchToolPath%" -delayOneSec > NUL
"%touchToolPath%" -kill > NUL
"%touchToolPath%" -delayOneSec > NUL
"%touchToolPath%" -delayOneSec > NUL
ECHO OK

ECHO Validating T2 device...
"%touchToolPath%" -validateT2Device > NUL
IF ERRORLEVEL 1 GOTO :invalidDeviceError
ECHO OK

ECHO Checking battery level...
"%touchToolPath%" -checkBatteryLevel > NUL
IF ERRORLEVEL 1 GOTO lowBatteryError
ECHO OK

ECHO Disabling power button...
"%touchToolPath%" -disablePowerOff > NUL
ECHO OK

ECHO Configuring settings...
MKDIR "%settingsFolderPath%" > NUL 2> NUL
ECHO OK

ECHO Deleting existing calibrations...
RMDIR /s /q "%calibrationsFolderPath%" > NUL 2> NUL
ECHO OK

ECHO Copying new calibrations...
MKDIR "%calibrationsFolderPath%" > NUL 2> NUL
COPY "%calibrationsSourceFolderPath%"* "%calibrationsFolderPath%" > NUL 2> NUL
ECHO OK

ECHO UPDATING T2
ECHO ***********
ECHO Updating Bootloader...
"%updateToolPath%" /u bootloader,raw,%backupFolderPath%\%bootloaderImage%
ECHO Updating Configblock
"%updateToolPath%" /u configblock,raw,%backupFolderPath%\%configBlockFile%
ECHO Updating Splash Screen
"%updateToolPath%" /u splashscreen,raw,%backupFolderPath%\%splashImage%
ECHO Updating OS
"%updateToolPath%" /u os,bin,%backupFolderPath%\%wince7%
ECHO Updating Registry
"%updateToolPath%" /u registry,raw,%backupFolderPath%\%registryFile%
ECHO Updating Flash Filesystem
"%updateToolPath%" /u filesystem,raw,%backupFolderPath%\%filesystemFile%
ECHO IMAGE UPDATE: DONE

ECHO ReEnabling power button...
"%touchToolPath%" -enablePowerOff > NUL
ECHO OK

ECHO Disabling shutdown delay...
"%touchToolPath%" -disableShutdownDelay > NUL
ECHO OK

ECHO.
ECHO Successfully updated firmware!
ECHO Please remove USB drive and restart device!
GOTO end

:invalidDeviceError
ECHO ERROR: No valid T2 device detected! Cannot apply update!
GOTO end

:lowBatteryError
ECHO ERROR: Device's battery level is below 50%. Cannot start update!
ECHO Disabling shutdown delay...
"%touchToolPath%" -disableShutdownDelay > NUL
ECHO OK
ECHO Please restart and charge device and try again!

:end
PAUSE > NUL

:endOfFile